# waterrocketpy


[![image](https://img.shields.io/pypi/v/waterrocketpy.svg)](https://pypi.python.org/pypi/waterrocketpy)
[![image](https://img.shields.io/conda/vn/conda-forge/waterrocketpy.svg)](https://anaconda.org/conda-forge/waterrocketpy)


**A modular Python package for simulating water rockets.**


-   Free software: MIT License
-   Documentation: https://Cube002.github.io/waterrocketpy
    

## Features

-   TODO
